pub enum TransactionError<P: PendingManager> {
ReadOnly,
Conflict,
Discard,
LargeTxn,
Manager(P::Error),
}Expand description
Error type for the transaction.
Variants
ReadOnly
Returned if an update function is called on a read-only transaction.
Conflict
Returned when a transaction conflicts with another transaction. This can happen if the read rows had been updated concurrently by another transaction.
Discard
Returned if a previously discarded transaction is re-used.
LargeTxn
Returned if too many writes are fit into a single transaction.
Manager(P::Error)
Returned if the transaction manager error occurs.